GoogleApi.Content.V2.Model.AccountsCustomBatchResponseEntry (google_api_content v0.41.2) View Source
A batch entry encoding a single non-batch accounts response.
Attributes
account(type:GoogleApi.Content.V2.Model.Account.t, default:nil) - The retrieved, created, or updated account. Not defined if the method wasdelete,claimwebsiteorlink.batchId(type:integer(), default:nil) - The ID of the request entry this entry responds to.errors(type:GoogleApi.Content.V2.Model.Errors.t, default:nil) - A list of errors defined if and only if the request failed.kind(type:String.t, default:content#accountsCustomBatchResponseEntry) - Identifies what kind of resource this is. Value: the fixed string "content#accountsCustomBatchResponseEntry"linkStatus(type:String.t, default:nil) - Deprecated. This field is never set.Acceptable values are:
- "
active" - "
inactive" - "
pending"
- "
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.Content.V2.Model.AccountsCustomBatchResponseEntry{
account: GoogleApi.Content.V2.Model.Account.t(),
batchId: integer(),
errors: GoogleApi.Content.V2.Model.Errors.t(),
kind: String.t(),
linkStatus: String.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.