GoogleApi.Content.V21.Api.Datafeeds (google_api_content v0.41.2) View Source
API calls for all endpoints tagged Datafeeds.
Link to this section Summary
Functions
Deletes, fetches, gets, inserts and updates multiple datafeeds in a single request.
Deletes a datafeed configuration from your Merchant Center account.
Invokes a fetch for the datafeed in your Merchant Center account.
Retrieves a datafeed configuration from your Merchant Center account.
Registers a datafeed configuration with your Merchant Center account.
Lists the configurations for datafeeds in your Merchant Center account.
Updates a datafeed configuration of your Merchant Center account. Any fields that are not provided are deleted from the resource.
Link to this section Functions
content_datafeeds_custombatch(connection, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_custombatch(Tesla.Env.client(), keyword(), keyword()) :: {:ok, GoogleApi.Content.V21.Model.DatafeedsCustomBatchResponse.t()} | {:ok, Tesla.Env.t()} | {:error, any()}
Deletes, fetches, gets, inserts and updates multiple datafeeds in a single request.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead. -
:body(type:GoogleApi.Content.V21.Model.DatafeedsCustomBatchRequest.t) -
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %GoogleApi.Content.V21.Model.DatafeedsCustomBatchResponse{}}on success -
{:error, info}on failure
content_datafeeds_delete(connection, merchant_id, datafeed_id, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_delete( Tesla.Env.client(), String.t(), String.t(), keyword(), keyword() ) :: {:ok, nil} | {:ok, Tesla.Env.t()} | {:error, any()}
Deletes a datafeed configuration from your Merchant Center account.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
merchant_id(type:String.t) - The ID of the account that manages the datafeed. This account cannot be a multi-client account. -
datafeed_id(type:String.t) - The ID of the datafeed. -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead.
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %{}}on success -
{:error, info}on failure
content_datafeeds_fetchnow(connection, merchant_id, datafeed_id, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_fetchnow( Tesla.Env.client(), String.t(), String.t(), keyword(), keyword() ) :: {:ok, GoogleApi.Content.V21.Model.DatafeedsFetchNowResponse.t()} | {:ok, Tesla.Env.t()} | {:error, any()}
Invokes a fetch for the datafeed in your Merchant Center account.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
merchant_id(type:String.t) - The ID of the account that manages the datafeed. This account cannot be a multi-client account. -
datafeed_id(type:String.t) - The ID of the datafeed to be fetched. -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead.
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %GoogleApi.Content.V21.Model.DatafeedsFetchNowResponse{}}on success -
{:error, info}on failure
content_datafeeds_get(connection, merchant_id, datafeed_id, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_get( Tesla.Env.client(), String.t(), String.t(), keyword(), keyword() ) :: {:ok, GoogleApi.Content.V21.Model.Datafeed.t()} | {:ok, Tesla.Env.t()} | {:error, any()}
Retrieves a datafeed configuration from your Merchant Center account.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
merchant_id(type:String.t) - The ID of the account that manages the datafeed. This account cannot be a multi-client account. -
datafeed_id(type:String.t) - The ID of the datafeed. -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead.
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %GoogleApi.Content.V21.Model.Datafeed{}}on success -
{:error, info}on failure
content_datafeeds_insert(connection, merchant_id, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_insert(Tesla.Env.client(), String.t(), keyword(), keyword()) :: {:ok, GoogleApi.Content.V21.Model.Datafeed.t()} | {:ok, Tesla.Env.t()} | {:error, any()}
Registers a datafeed configuration with your Merchant Center account.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
merchant_id(type:String.t) - The ID of the account that manages the datafeed. This account cannot be a multi-client account. -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead. -
:body(type:GoogleApi.Content.V21.Model.Datafeed.t) -
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %GoogleApi.Content.V21.Model.Datafeed{}}on success -
{:error, info}on failure
content_datafeeds_list(connection, merchant_id, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_list(Tesla.Env.client(), String.t(), keyword(), keyword()) :: {:ok, GoogleApi.Content.V21.Model.DatafeedsListResponse.t()} | {:ok, Tesla.Env.t()} | {:error, any()}
Lists the configurations for datafeeds in your Merchant Center account.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
merchant_id(type:String.t) - The ID of the account that manages the datafeeds. This account cannot be a multi-client account. -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead. -
:maxResults(type:integer()) - The maximum number of products to return in the response, used for paging. -
:pageToken(type:String.t) - The token returned by the previous request.
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %GoogleApi.Content.V21.Model.DatafeedsListResponse{}}on success -
{:error, info}on failure
content_datafeeds_update(connection, merchant_id, datafeed_id, optional_params \\ [], opts \\ [])
View SourceSpecs
content_datafeeds_update( Tesla.Env.client(), String.t(), String.t(), keyword(), keyword() ) :: {:ok, GoogleApi.Content.V21.Model.Datafeed.t()} | {:ok, Tesla.Env.t()} | {:error, any()}
Updates a datafeed configuration of your Merchant Center account. Any fields that are not provided are deleted from the resource.
Parameters
-
connection(type:GoogleApi.Content.V21.Connection.t) - Connection to server -
merchant_id(type:String.t) - The ID of the account that manages the datafeed. This account cannot be a multi-client account. -
datafeed_id(type:String.t) - The ID of the datafeed. -
optional_params(type:keyword()) - Optional parameters-
:alt(type:String.t) - Data format for the response. -
:fields(type:String.t) - Selector specifying which fields to include in a partial response. -
:key(type:String.t) - API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token. -
:oauth_token(type:String.t) - OAuth 2.0 token for the current user. -
:prettyPrint(type:boolean()) - Returns response with indentations and line breaks. -
:quotaUser(type:String.t) - An opaque string that represents a user for quota purposes. Must not exceed 40 characters. -
:userIp(type:String.t) - Deprecated. Please use quotaUser instead. -
:body(type:GoogleApi.Content.V21.Model.Datafeed.t) -
-
-
opts(type:keyword()) - Call options
Returns
-
{:ok, %GoogleApi.Content.V21.Model.Datafeed{}}on success -
{:error, info}on failure