GoogleApi.Content.V21.Model.OrderPickupDetails (google_api_content v0.41.2) View Source
Attributes
address(type:GoogleApi.Content.V21.Model.OrderAddress.t, default:nil) - Address of the pickup location where the shipment should be sent. Note thatrecipientNamein the address is the name of the business at the pickup location.collectors(type:list(GoogleApi.Content.V21.Model.OrderPickupDetailsCollector.t), default:nil) - Collectors authorized to pick up shipment from the pickup location.locationId(type:String.t, default:nil) - ID of the pickup location.pickupType(type:String.t, default:nil) - The pickup type of this order.Acceptable values are:
- "
merchantStore" - "
merchantStoreCurbside" - "
merchantStoreLocker" - "
thirdPartyPickupPoint" - "
thirdPartyLocker"
- "
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.Content.V21.Model.OrderPickupDetails{
address: GoogleApi.Content.V21.Model.OrderAddress.t(),
collectors: [GoogleApi.Content.V21.Model.OrderPickupDetailsCollector.t()],
locationId: String.t(),
pickupType: String.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.