GoogleApi.Content.V21.Model.OrdersRefundItemRequest (google_api_content v0.41.2) View Source
Attributes
items(type:list(GoogleApi.Content.V21.Model.OrdersCustomBatchRequestEntryRefundItemItem.t), default:nil) - The items that are refunded. Either Item or Shipping must be provided in the request.operationId(type:String.t, default:nil) - The ID of the operation. Unique across all operations for a given order.reason(type:String.t, default:nil) - The reason for the refund.Acceptable values are:
- "
shippingCostAdjustment" - "
priceAdjustment" - "
taxAdjustment" - "
feeAdjustment" - "
courtesyAdjustment" - "
adjustment" - "
customerCancelled" - "
noInventory" - "
productNotAsDescribed" - "
undeliverableShippingAddress" - "
wrongProductShipped" - "
lateShipmentCredit" - "
deliveredLateByCarrier" - "
productArrivedDamaged"
- "
reasonText(type:String.t, default:nil) - The explanation of the reason.shipping(type:GoogleApi.Content.V21.Model.OrdersCustomBatchRequestEntryRefundItemShipping.t, default:nil) - The refund on shipping. Optional, but either Item or Shipping must be provided in the request.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.Content.V21.Model.OrdersRefundItemRequest{
items: [
GoogleApi.Content.V21.Model.OrdersCustomBatchRequestEntryRefundItemItem.t()
],
operationId: String.t(),
reason: String.t(),
reasonText: String.t(),
shipping:
GoogleApi.Content.V21.Model.OrdersCustomBatchRequestEntryRefundItemShipping.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.