GoogleApi.Content.V21.Model.OrdersRefundOrderRequest (google_api_content v0.41.2) View Source
Attributes
amount(type:GoogleApi.Content.V21.Model.MonetaryAmount.t, default:nil) - The amount that is refunded. If this is not the first refund for the order, this should be the newly refunded amount.fullRefund(type:boolean(), default:nil) - If true, the full order will be refunded, including shipping. If this is true, amount should not be provided and will be ignored.operationId(type:String.t, default:nil) - The ID of the operation. Unique across all operations for a given order.reason(type:String.t, default:nil) - The reason for the refund.Acceptable values are:
- "
courtesyAdjustment" - "
other"
- "
reasonText(type:String.t, default:nil) - The explanation of the reason.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
t() :: %GoogleApi.Content.V21.Model.OrdersRefundOrderRequest{
amount: GoogleApi.Content.V21.Model.MonetaryAmount.t(),
fullRefund: boolean(),
operationId: String.t(),
reason: String.t(),
reasonText: String.t()
}
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.