GoogleApi.Content.V21.Model.OrdersUpdateShipmentRequest (google_api_content v0.41.2) View Source
Attributes
carrier(type:String.t, default:nil) - The carrier handling the shipment. Not updated if missing. Seeshipments[].carrierin the Orders resource representation for a list of acceptable values.deliveryDate(type:String.t, default:nil) - Date on which the shipment has been delivered, in ISO 8601 format. Optional and can be provided only ifstatusisdelivered.lastPickupDate(type:String.t, default:nil) - Date after which the pickup will expire, in ISO 8601 format. Required only when order is buy-online-pickup-in-store(BOPIS) andstatusisready for pickup.operationId(type:String.t, default:nil) - The ID of the operation. Unique across all operations for a given order.readyPickupDate(type:String.t, default:nil) - Date on which the shipment has been ready for pickup, in ISO 8601 format. Optional and can be provided only ifstatusisready for pickup.shipmentId(type:String.t, default:nil) - The ID of the shipment.status(type:String.t, default:nil) - New status for the shipment. Not updated if missing.Acceptable values are:
- "
delivered" - "
undeliverable" - "
readyForPickup"
- "
trackingId(type:String.t, default:nil) - The tracking ID for the shipment. Not updated if missing.undeliveredDate(type:String.t, default:nil) - Date on which the shipment has been undeliverable, in ISO 8601 format. Optional and can be provided only ifstatusisundeliverable.
Link to this section Summary
Functions
Unwrap a decoded JSON object into its complex fields.
Link to this section Types
Specs
Link to this section Functions
Specs
Unwrap a decoded JSON object into its complex fields.